@@ -16,46 +16,57 @@
  *   You should have received a copy of the GNU General Public License
  *   along with PhpCompta; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * $Revision: 1.23 $
 */
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
+/*! \file
+ * \brief Administration of the repository : creation of user, folder, security, 
+ *        templates... Accessible only by the administrator
+ */
 
 include_once("ac_common.php");
 include_once("postgres.php");
 include_once("debug.php");
-html_page_start($g_UserProperty['use_theme']);
-echo_debug("entering admin_repo");
+include_once("user_menu.php");
+$rep=DbConnect();
+include_once ("class_user.php");
+$User=new cl_user($rep);
+$User->Check();
 
-CheckUser();
-if ($g_UserProperty['use_admin'] != 1) {
+
+html_page_start($User->theme);
+echo_debug('admin_repo.php',__LINE__,"entering admin_repo");
+
+if ($User->admin != 1) {
   html_page_stop();
   return;
 }
-include ("top_menu_compta.php");
 
 echo '<H2 class="info"> Administration Globale</H2>';
-if ( ! isset ($g_dossier) ) $g_dossier=0;
-ShowMenuAdminGlobalRight($g_dossier);
-ShowMenuAdminGlobal();
+echo "<div>".MenuAdmin()."</div>";
+
+
+
+
 ?>
-<DIV class="redcontent">
+<DIV >
 <?
 if ( isset ($_GET["action"]) ) {
   if ( $_GET["action"]=="user_mgt" ) {
     // Add user
     if ( isset ($_POST["LOGIN"]) ) {
       $cn=DbConnect();
-      $pass5=md5($PASS);
-      $Res=ExecSql($cn,"insert into ac_users(use_first_name,use_name,use_login,use_active,use_pass
-                        ,use_usertype)
-                    values ('".$_POST["FNAME"]."','".$_POST["LNAME"]."','".$_POST["LOGIN"]."',1,'$pass5',
-                    'user')");
+      $pass5=md5($_POST['PASS']);
+      $Res=ExecSql($cn,"insert into ac_users(use_first_name,use_name,use_login,use_active,use_pass)
+                    values ('".$_POST["FNAME"]."','".$_POST["LNAME"]."','".$_POST["LOGIN"]."',1,'$pass5')");
     } //SET login
 
     // Show all the existing user on 7 columns
     $cn=GetAllUser();
-    echo_debug("Array = $cn");
+    echo_debug('admin_repo.php',__LINE__,"Array = $cn");
     $compteur=0;
 ?>
+<h2>Gestion Utilisateurs</h2>
 <TABLE><TR>
 <?
     if ( $cn != null ) {
@@ -80,8 +91,8 @@ if ( isset ($_GET["action"]) ) {
 </TABLE>
 <TABLE> <TR> 
 <form action="admin_repo.php?action=user_mgt" method="POST">
-<TD><H3>Add User<H3></TD></TR>
-<?
+<TD><H3>Ajout d'utilisateur<H3></TD></TR>
+<? //'
     echo '<TR><TD> First Name </TD><TD><INPUT TYPE="TEXT" NAME="FNAME"></TD>';
     echo '<TD> Last Name </TD><TD><INPUT TYPE="TEXT" NAME="LNAME"></TD></TR>';
     echo '<TR><TD> login </TD><TD><INPUT TYPE="TEXT" NAME="LOGIN"></TD>';
@@ -102,7 +113,7 @@ if ( isset ($_GET["action"]) ) {
       $cn=DbConnect();
       $dos=trim($_POST["DATABASE"]);
       if (strlen($dos)==0) {
-	echo ("Dataname is empty");
+	echo ("Dataname name is empty");
 	exit -1;
       }
       $desc=FormatString($_POST["DESCRIPTION"]);
@@ -112,14 +123,14 @@ if ( isset ($_GET["action"]) ) {
       // Database created
       $l_id=GetDbId($dos);
       if ( $l_id != 0) {
-	$Sql=sprintf("CREATE DATABASE DOSSIER%d encoding='ISO8859-1' TEMPLATE MOD%d",$l_id,$_POST["FMOD_ID"]);
+	$Sql=sprintf("CREATE DATABASE %sDOSSIER%d encoding='ISO8859-1' TEMPLATE %sMOD%d",domaine,$l_id,domaine,$_POST["FMOD_ID"]);
 	echo_debug($Sql);
 	ExecSql($cn,$Sql);
 	$Res=ExecSql($cn,"insert into jnt_use_dos (use_id,dos_id) values (1,$l_id)");
       } // if $l_id != 0
     } // $_POST[DATABASE]
 ?>
-    Dossier Management
+   <h2> Dossier Management</h2>
 
 <TABLE BORDER=1>
 <?
@@ -130,11 +141,14 @@ $template="";
 
  // show all dossiers
 if ( $Res != null ) {
-  echo "<TR>";
   foreach ( $Res as $Dossier) {
     
-    if ( $compteur%5 == 0 ) echo "</TR><TR>";
-    echo "<TD VALIGN=\"TOP\"> <B>$Dossier[dos_name]</B> <BR><I>  $Dossier[dos_description]</I></TD>";
+    if ( $compteur%2 == 0 ) 
+    	$cl='class="odd"';
+	else
+	$cl='class="even"';
+
+    echo "<TR $cl><TD VALIGN=\"TOP\"> <B>$Dossier[dos_name]</B> </TD><TD><I>  $Dossier[dos_description]</I></TD></TR>";
     $compteur++;
     
   }
@@ -153,11 +167,8 @@ if ( $count == 0 ) {
   } else {
     $template='<SELECT NAME=FMOD_ID>';
       for ($i=0;$i<$count;$i++) {
-	$mod=pg_fetch_array($Res,0);
-	$template.='<OPTION VALUE="'.$mod['mod_id'].'"> '.$mod['mod_name']." - ".$mod['mod_desc'];
-	/*	printf("<span> %s  %s </span>",
-	       $mod['mod_name'],$mod['mod_desc']);*/
-
+	$mod=pg_fetch_array($Res,$i);
+	$template.='<OPTION VALUE="'.$mod['mod_id'].'"> '.$mod['mod_name']." - ".substr($mod['mod_desc'],0,30);
       }// for
       $template.="</SELECT>";
     }// if count = 0
@@ -168,11 +179,11 @@ if ( $count == 0 ) {
  <FORM ACTION="admin_repo.php?action=dossier_mgt" METHOD="POST">
     <TABLE>
     <TR>
-    <TD> Name  <INPUT TYPE="TEXT" NAME="DATABASE"> </TD>
+    <TD> Name</td><td>  <INPUT TYPE="TEXT" NAME="DATABASE"> </TD>
     </TR><TR>
-    <TD> Description <INPUT TYPE="TEXT" NAME="DESCRIPTION" SIZE="30"> </TD>
+    <TD> Description</td><td>  <TEXTAREA COLS="60" ROWS="2" NAME="DESCRIPTION" ></TEXTAREA> </TD>
     </TR>
-    <TR> <TD><? echo $template; ?> </TD></TR>
+    <TR> <TD> Modle</td><td>  <? echo $template; ?> </TD></TR>
 
     <TR>
     <TD> <INPUT TYPE=SUBMIT VALUE="Create Folder"></TD>
@@ -196,28 +207,37 @@ if ( $count == 0 ) {
 		     "'".$mod_desc."')");
 	
 	// get the mod_id
-	$l_id=GetModeleId($cn,$mod_name);
+	$l_id=GetSequence($cn,'s_modid');
 	if ( $l_id != 0 ) {
-	  $Sql=sprintf("CREATE DATABASE MOD%d encoding='ISO8859-1' TEMPLATE DOSSIER%s",$l_id,$_POST["FMOD_DBID"]);
-	  ExecSql($cn,$Sql);
-	}
+	   $Sql=sprintf("CREATE DATABASE %sMOD%d encoding='ISO8859-1' TEMPLATE %sDOSSIER%s",domaine,$l_id,domaine,$_POST["FMOD_DBID"]);
+	   ExecSql($cn,$Sql);
+ 	}
       }// if $mod_name != null
+
+      $cn_mod=dbconnect($l_id,'mod');
       // Clean some tables 
-      $Res=ExecSql($cn,"truncate table jrn");
-      $Res=ExecSql($cn,"truncate table jrnx");
-      $Res=ExecSql($cn,"truncate table centralized");
-      $Res=ExecSql($cn,"truncate table stock_goods");
-
+      $Res=ExecSql($cn_mod,"truncate table jrn");
+      $Res=ExecSql($cn_mod,"truncate table jrnx");
+      $Res=ExecSql($cn_mod,"truncate table centralized");
+      $Res=ExecSql($cn_mod,"truncate table stock_goods");
+//	Reset the closed periode
+      $Res=ExecSql($cn_mod,"update parm_periode set p_closed='f'");
       // Reset Sequence
-      $Res=ExecSql($cn,"drop sequence s_jrn");
-      $Res=ExecSql($cn,"drop sequence s_jrn_op");
-      $Res=ExecSql($cn,"drop sequence s_centralized");
-      $Res=ExecSql($cn,"drop sequence s_stock_goods");
-
-      $Res=ExecSql($cn,"create sequence s_jrn");
-      $Res=ExecSql($cn,"create sequence s_jrn_op");
-      $Res=ExecSql($cn,"create sequence s_centralized");
-      $Res=ExecSql($cn,"create sequence s_stock_goods");
+      $a_seq=array('s_jrn','s_jrn_op','s_centralized','s_stock_goods');
+      foreach ($a_seq as $seq ) {
+      	$sql=sprintf("select setval('%s',1,false)",$seq);
+      	$Res=ExecSql($cn_mod,$sql);
+	}
+   	$sql="select jrn_def_id from jrn_def ";
+   	$Res=ExecSql($cn_mod,$sql);
+    	$Max=pg_NumRows($Res);
+    	for ($seq=0;$seq<$Max;$seq++) {
+	    $row=pg_fetch_array($Res,$seq);
+	    $sql=sprintf ("select setval('s_jrn_%d',1,false)",$row['jrn_def_id']);
+	    ExecSql($cn_mod,$sql);
+    	}
+      
+      
     }
     // Show all available templates
 
@@ -227,14 +247,30 @@ if ( $count == 0 ) {
     if ( $count == 0 ) {
       echo "No template available";
     } else {
-     
+      echo "<H2>Modles</H2>";
+
+      echo '<table width="100%" border="1">';
+      echo "<TR><TH>Nom</TH>".
+	"<TH>Description</TH>".
+	"</TR>";
+
       for ($i=0;$i<$count;$i++) {
-	$mod=pg_fetch_array($Res,0);
-	printf("<span> %s  %s </span>",
-	       $mod['mod_name'],$mod['mod_desc']);
+	$mod=pg_fetch_array($Res,$i);
+	printf('<TR>'.
+               '<TD><b> %s</b> </TD>'.
+	       '<TD><I> %s </I></TD>'.
+	       '</TR>',
+	       $mod['mod_name'],
+	       $mod['mod_desc']);
 
       }// for
+      echo "</table>";
     }// if count = 0
+      echo "Si vous voulez rcuprer toutes les adaptations d'un dossier ".
+	" dans un autre dossier, vous pouvez en faire un modle.".
+	" Seules les fiches, la structure des journaux, les priodes,... seront reprises ".
+	"et aucune donnes du dossier sur lequel le dossier est bas.";
+
     // Show All available folder
     $Res=ExecSql($cn,"select dos_id, dos_name,dos_description from ac_dossier
                       order by dos_name");
@@ -257,7 +293,7 @@ if ( $count == 0 ) {
 </TR>
 <TR>
     <TD>Description</TD>
-    <TD><INPUT TYPE="TEXTAREA" ROWS="4" COLS="30" NAME="FMOD_DESC"></TD>
+    <TD><TEXTAREA ROWS="2" COLS="60" NAME="FMOD_DESC"></Textarea></TD>
 </TR>
 <TR>
     <TD> Bas sur </TD>
