@@ -17,32 +17,38 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
-/* $Revision: 1.5 $ */
+/* $Revision: 1.16 $ */
+/*! \file
+ * \brief Show the detail of a operation in a popup windows
+ */
+
 include_once ("ac_common.php");
 include_once ("poste.php");
 include_once ("user_common.php");
-html_page_start($g_UserProperty['use_theme']);
-if ( ! isset ( $g_dossier ) ) {
+html_page_start($_SESSION['g_theme']);
+if ( ! isset ( $_SESSION['g_dossier'] ) ) {
   echo "You must choose a Dossier ";
-  //  phpinfo();
   exit -2;
 }
 include_once ("postgres.php");
 include_once("jrn.php");
 /* Admin. Dossier */
-CheckUser();
+$rep=DbConnect();
+include_once ("class_user.php");
+$User=new cl_user($rep);
+$User->Check();
+
+if ( isset( $_GET['$p_jrn'] )) {
+  $p_jrn=$_GE['p_jrn'];
+  $_SESSION[ "p_jrn"]=$p_jrn;
 
-if ( isset( $p_jrn )) {
-  session_register("g_jrn");
-  $g_jrn=$p_jrn;
 }
-$l_Db=sprintf("dossier%d",$g_dossier);
-$cn=DbConnect($l_Db);
+$cn=DbConnect($_SESSION['g_dossier']);
 $jrn_op=$_GET['jrn_op'];
 list ($l_array,$max_deb,$max_cred)=GetData($cn,$jrn_op);
 foreach ($l_array as $key=>$element) {
   ${"e_$key"}=$element;
-  echo_debug("jrn_op_detail.php e_$key =$element");
+  echo_debug('jrn_op_detail.php',__LINE__,"jrn_op_detail.php e_$key =$element");
 }
 
 echo '<div align="center"> Opration </div>';
@@ -55,26 +61,32 @@ echo '</DIV>';
 if ( isset ($e_ech) ) {
   echo "<DIV> Echeance $e_ech </DIV>";
 }
+echo '<div style="background-color:#BFC2D5;">';
+
 for ( $i = 0; $i < $max_deb;$i++) {
-  $lib=GetPosteLibelle($g_dossier,${"e_class_deb$i"}); 
-  echo '<div style="background-color:#BFC2D5;">';
-  echo ${"e_class_deb$i"}." $lib    "."<B>".${"e_mont_deb$i"}."</B>";
+  $lib=GetPosteLibelle($_SESSION['g_dossier'],${"e_class_deb$i"}); 
+  echo ${"e_class_deb$i"}." $lib    "."<B>".${"e_mont_deb$i"}."</B>.<br>";
+
+}
   echo "</div>";
-}
+  echo '<div style="background-color:#E8F4FF;margin-left:50px;">';
 for ( $i = 0; $i < $max_cred;$i++) {
-  $lib=GetPosteLibelle($g_dossier,${"e_class_cred$i"});
-  echo '<div style="background-color:#E8F4FF;">';
-  echo ${"e_class_cred$i"}."  $lib   "."<B>".${"e_mont_cred$i"}."</B>";
-  echo '</div>';
+  $lib=GetPosteLibelle($_SESSION['g_dossier'],${"e_class_cred$i"});
+
+  echo ${"e_class_cred$i"}."  $lib   "."<B>".${"e_mont_cred$i"}."</B><br>";
 }
+  echo '</div>';
+
 $a=GetConcerned($cn,$e_jr_id);
 
 if ( $a != null ) {
-  foreach ($a as $key => $element) {
     echo "operation concerne <br>";
+    echo '<div style="margin-left:30px;">';
+  foreach ($a as $key => $element) {
 
-    echo "<A HREF=\"jrn_op_detail.php?jrn_op=".GetGrpt($cn,$element)."\"> ".GetInternal($cn,$element)."</A><br>";
+    echo "<A class=\"detail\" HREF=\"jrn_op_detail.php?jrn_op=".GetGrpt($cn,$element)."\"> ".GetInternal($cn,$element)."</A>";
   }//for
+  echo "</div>";
 }// if ( $a != null ) {
 ?>
 <input type="button" onClick="window.close()" value="Fermer">
