@@ -1,6 +1,4 @@
 <?
-
-
 /*
  *   This file is part of PhpCompta.
  *
@@ -18,10 +16,17 @@
  *   along with PhpCompta; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
-// $Revision: 1.16 $
+// $Revision: 1.47 $
+/*! \file
+ * \brief Contains all the variable + the javascript
+ * and some parameter 
+ */
+
 define ("phpcompta_password","dany");
+define ("domaine","");
+
+define ("DEBUG","false");
 
 // securite correspond a la table 
 // action
@@ -43,16 +48,30 @@ define ("GJRN",7);
 define ("PARM",8);
 // Gestion de la scurit
 define ("SECU",9);
+// gestion devise
+define ("DEVISE",18);
+// gestion Priode
+define ("PERIODE",19);
+// Voir la balance des compte
+define ("BALANCE",20);
 // Access  la centralisation
 define ("CENTRALIZE",10);
 define ("VEN",11);
 define ("BQE",12);
 define ("ODS",13);
-define ("ACH",14);
+
+//!\enum Security 
+define("SEC_ACTION", 28); // Module Suivi Document
+define("CLIENT",22); // Module Client
+define("SUPPL",24); // Module Fournisseur 
+define("ADMIN",26); //  Module Administration	 
+define("SEC_GESTION",30); //  Module Gestion
+
 define ("FICHE_WRITE",15);
 define ("STOCK_WRITE",16);
 define ("STOCK_READ",17);
-
+define ("EXP_IMP_ECR",21);
+define ("IMP_BQE",22);
 // Erreur
 define ("NOERROR",0);
 define ("BADPARM",1);
@@ -70,12 +89,16 @@ define ("LAST",1);
 define ("FIRST",0);
 define ("ERROR",12);
 
+//!\enum ACTION  defines document_type for action
+define('ACTION','1,5,6,7,8');
+
 //valeurs standardd
 define ("YES",1);
 define ("NO",0);
 define ("OPEN",1);
 define ("CLOSED",0);
 define ("NOTCENTRALIZED",3);
+define ("ALL",4);
 
 // Pour les ShowMenuComptaLeft
 define ("MENU_FACT",1);
@@ -91,24 +114,34 @@ define ("ATTR_DEF_NAME",1);
 define ("ATTR_DEF_PRIX_ACHAT",7);
 define ("ATTR_DEF_PRIX_VENTE",6);
 define ("ATTR_DEF_TVA",2);
+define ("ATTR_DEF_NUMTVA",13);
 define ("ATTR_DEF_ADRESS",14);
 define ("ATTR_DEF_CP",15);
 define ("ATTR_DEF_PAYS",16);
 define ("ATTR_DEF_STOCK",19);
+define ("ATTR_DEF_TEL",17);
+define ("ATTR_DEF_EMAIL",18);
+define ("ATTR_DEF_COMPANY",25);
+define ("ATTR_DEF_FAX",26);
+
 
 define ("FICHE_TYPE_CLIENT",9);
 define ("FICHE_TYPE_VENTE",1);
 define ("FICHE_TYPE_FOURNISSEUR",8);
 define ("FICHE_TYPE_FIN",4);
+define ("FICHE_TYPE_CONTACT",16);
 define ("FICHE_TYPE_ADM_TAX",14);
-
-define ("JS_SEARCH_POSTE","<SCRIPT>function SearchPoste(p_sessid,p_ctl)
+define ("ATTR_DEF_DEPENSE_NON_DEDUCTIBLE",20);
+define ("ATTR_DEF_TVA_NON_DEDUCTIBLE",21);
+define ("ATTR_DEF_TVA_NON_DEDUCTIBLE_RECUP",22);
+define ("ATTR_DEF_QUICKCODE",23);
+define ("JS_SEARCH_POSTE","<SCRIPT language=\"javascript\">function SearchPoste(p_sessid,p_ctl,p_jrn)
      {
-       var win=window.open('poste_search.php?p_ctl='+p_ctl+'&PHPSESSID='+p_sessid,'Cherche','toolbar=no,width=600,height=600,scrollbars=yes,resizable=yes');
+       var win=window.open('poste_search.php?p_jrn='+p_jrn+'&p_ctl='+p_ctl+'&PHPSESSID='+p_sessid,'Cherche','toolbar=no,width=600,height=600,scrollbars=yes,resizable=yes');
     } 
-function SearchPosteFilter(p_sessid,p_ctl,p_filter)
+function SearchPosteFilter(p_sessid,p_ctl,p_filter,jrn)
      {
-       var win=window.open('poste_search.php?p_ctl='+p_ctl+'&PHPSESSID='+p_sessid+'&filter='+p_filter,'Cherche','toolbar=no,width=600,height=600,scrollbars=yes,resizable=yes');
+       var win=window.open('poste_search.php?p_jrn='+jrn+'&p_ctl='+p_ctl+'&PHPSESSID='+p_sessid+'&filter='+p_filter,'Cherche','toolbar=no,width=600,height=600,scrollbars=yes,resizable=yes');
     } 
 	 function GetIt() {
 	   window.close();	
@@ -118,66 +151,113 @@ function SetItChild(p_ctl,p_value) {
 	window.close();
 }
 function SetItParent(p_ctl,p_value) {
-	document.forms[0].eval(p_ctl).value=p_value;
+
+	var f=document.getElementsByName(p_ctl);
+	for (var h=0; h < f.length; h++) {
+		f[h].value=p_value;
+		}
+	
+}
+/* SetValue( p_ctl,p_value )
+/* p_ctl is the name of the control
+/* p_value is the value to set in
+*/
+function SetValue(p_ctl,p_value) 
+{
+
+	var f=document.getElementsByName(p_ctl);
+	for (var h=0; h < f.length; h++) {
+		f[h].value=p_value;
+		}
+	
+
 }
 	</SCRIPT>"
 );
-define ("JS_SHOW_TVA","<SCRIPT>function ShowTva(p_sessid,ctl)
+define ("JS_SHOW_TVA","<SCRIPT language=\"javascript\">
+function ShowTva(p_sessid,ctl)
      {
        var win=window.open('show_tva.php?ctl='+ctl+'&PHPSESSID='+p_sessid,'Montre','scrollbar,toolbar=no,width=300,height=300,resizable=yes');
     } 
-	 function GetIt(ctl,tva_id) {
-           self.opener.SetIt(ctl,tva_id)
-	   window.close();	
-	} 
-function SetIt(ctl,tva_id)
-{
-document.forms[0].eval(ctl).value=tva_id;
-}
+ function GetIt(ctl,tva_id) {
+   self.opener.SetValue(ctl,tva_id)
+   window.close();	
+} 
+
 	</SCRIPT>"
 );
 
-define ("JS_VIEW_JRN_DETAIL","<script>function viewDetail(p_value,p_sessid)
+define ("JS_VIEW_JRN_DETAIL","<script language=\"javascript\">function viewDetail(p_value,p_sessid)
 		{
 			var win=window.open('jrn_op_detail.php?jrn_op='+p_value+'&PHPSESSID='+p_sessid,'Cherche','toolbar=no,width=400,height=400,scrollbars=yes,resizable=yes');
 		}
 
 	</script>");
-define ("JS_VIEW_JRN_CANCEL","<script>function cancelOperation(p_value,p_sessid)
+define ("JS_VIEW_JRN_CANCEL","<script  language=\"javascript\" >function cancelOperation(p_value,p_sessid,p_jrn)
 		{
-			var win=window.open('annulation.php?jrn_op='+p_value+'&PHPSESSID='+p_sessid,'Cancel it','toolbar=no,width=400,height=400,scrollbars=yes,resizable=yes');
+			var win=window.open('annulation.php?p_jrn='+p_jrn+'&jrn_op='+p_value+'&PHPSESSID='+p_sessid,'Annule','toolbar=no,width=400,height=400,scrollbars=yes,resizable=yes');
 		}
 function RefreshMe() {
 window.location.reload();
 }
 	</script>");
-define ("JS_VIEW_JRN_MODIFY","<script>function modifyOperation(p_value,p_sessid)
+define ("JS_VIEW_JRN_MODIFY","<script  language=\"javascript\">function modifyOperation(p_value,p_sessid,p_jrn)
 		{
-			var win=window.open('modify_op.php?action=update&line='+p_value+'&PHPSESSID='+p_sessid,'Modify it','toolbar=no,width=500,height=400,scrollbars=yes,resizable=yes');
+			var win=window.open('modify_op.php?action=update&p_jrn='+p_jrn+'&line='+p_value+'&PHPSESSID='+p_sessid,'Modifie','toolbar=no,width=500,height=400,scrollbars=yes,resizable=yes');
 		}
 function RefreshMe() {
 window.location.reload();
 }
 	function dropLink(p_value,p_value2,p_sessid) {
-	var win=window.open('modify_op.php?action=delete&line='+p_value+'&line2='+p_value2+'&PHPSESSID='+p_sessid,'delete link it','toolbar=no,width=500,height=400,scrollbars=yes,resizable=yes');
+	var win=window.open('modify_op.php?action=delete&line='+p_value+'&line2='+p_value2+'&PHPSESSID='+p_sessid,'Liaison','toolbar=no,width=500,height=400,scrollbars=yes,resizable=yes');
 		}
 
 	
 	</script>");
+define ("JS_UPDATE_PCMN","<script  language=\"javascript\">function PcmnUpdate(p_value,p_lib,p_parent,p_sessid)
+		{
+			var win=window.open('line_update.php?l='+p_value+'&n='+p_lib+'&p='+p_parent+'&PHPSESSID='+p_sessid,'Modifie','toolbar=no,width=500,height=400,scrollbars=yes,resizable=yes');
+		}
+function RefreshMe() {
+	window.location.reload();
+	}
+	
+	
+	</script>");
+
 define ("JS_SEARCH_CARD","
-<script>
+<script  language=\"javascript\">
+function showfiche(p_sessid,qcode)
+{
+  var a=window.open('show_fiche.php?PHPSESSID='+p_sessid+'&q='+qcode,'','toolbar=no,width=350,height=450,scrollbar=yes');
+  
+}
+
 /* type must be cred or deb and name is
  * the control's name
 */
-function SearchCard(p_sessid,type,name)
+function SearchCard(p_sessid,type,name,jrn)
 {
-   var a=window.open('fiche_search.php?PHPSESSID='+p_sessid+'&type='+type+'&name='+name,'item','toolbar=no,width=350,height=450,scrollbars=yes');
+   var a=window.open('fiche_search.php?p_jrn='+jrn+'&PHPSESSID='+p_sessid+'&type='+type+'&name='+name,'item','toolbar=no,width=350,height=450,scrollbars=yes');
 }
-function NewCard(p_sessid,type,name)
+	function NewCard(p_sessid,type,name,jrn)
 {
-   var a=window.open('fiche_new.php?PHPSESSID='+p_sessid+'&type='+type+'&name='+name,'item','toolbar=no,width=350,height=450,scrollbars=yes');
+   var a=window.open('fiche_new.php?p_jrn='+jrn+'&PHPSESSID='+p_sessid+'&type='+type+'&name='+name,'item','toolbar=no,width=350,height=450,scrollbars=yes');
 }
+/* SetValue( p_ctl,p_value )
+/* p_ctl is the name of the control
+/* p_value is the value to set in
+*/
+function SetValue(p_ctl,p_value) 
+{
 
+	var f=document.getElementsByName(p_ctl);
+	for (var h=0; h < f.length; h++) {
+		f[h].value=p_value;
+		}
+	
+
+}
 /* Parameters 
  * i = ctl _name
  * p_id = code id (fiche.f_id)
@@ -189,8 +269,7 @@ function NewCard(p_sessid,type,name)
  */
   function SetData(i,p_id,p_label,p_sell,p_buy,p_tva_id, p_tva_label)
 {
-	document.form_detail.eval(i).value=p_id;
-	
+	SetValue(i,p_id);
 	// for the form we use 1. and for span 2.    
 	//1. document.form_detail.eval(a).value=p_buy;
 	//2. document.getElementById(a).innerHTML=p_sell;
@@ -204,7 +283,7 @@ function NewCard(p_sessid,type,name)
 	// if the object exist
  	var e=document.getElementsByName(a)  
 	  if ( e.length != 0 ) {
-	    document.form_detail.eval(a).value=p_sell;
+	    SetValue(a,p_sell);
 
 	}
 
@@ -213,14 +292,14 @@ function NewCard(p_sessid,type,name)
 	// if the object exist
  	var e=document.getElementsByName(a)  
         if ( e.length != 0 ) {
-	  document.form_detail.eval(a).value=p_buy;
+	  SetValue(a,p_buy);
 	}
 	// Compute name of  tva_id  ctl 
 	var a=i+'_tva_id';
 	// if the object exist
  	var e=document.getElementsByName(a)  
         if ( e.length != 0 ) {
-	  document.form_detail.eval(a).value=p_tva_id;
+	  SetValue(a,p_tva_id);
 	}
 
 	// Compute name of  tva_label ctl 
@@ -238,7 +317,7 @@ function NewCard(p_sessid,type,name)
 ");
 // concerned operation
 define ("JS_CONCERNED_OP","
-<script>
+<script  language=\"javascript\">
 
 function SearchJrn(p_sessid,p_ctl)
 {
@@ -248,54 +327,56 @@ function GetIt(p_ctl,p_value) {
   self.opener.SetIt(p_value,p_ctl);
 	window.close();	
 }
+/* SetValue( p_ctl,p_value )
+/* p_ctl is the name of the control
+/* p_value is the value to set in
+*/
 function SetIt(p_value,p_ctl) {
-  document.forms[0].eval(p_ctl).value=p_value;
 	
+	var f=document.getElementsByName(p_ctl);
+	for (var h=0; h < f.length; h++) {
+		f[h].value=p_value;
+		}
+	
+
 }
 
 
 </script>
 ");
 // One line calculator
-define ("JS_CALC_LINE","
-
-<form name=\"calc_line\" onSubmit=\"cal()\">
-<input type=\"text\" size=\"20\" name=\"calculator\" onBlur=\"cal()\">
-Answer:<span id=\"name\"></span>
-<br>
-
-<!-- <input type=\"button\" name=\"B1\" value=\"Calculate\" > -->
-
-<input type=\"reset\" name=\"B2\" value=\"Reset\"><br>
-
-
-</form>
-<SCRIPT>
-
-function cal()
-{
-  document.getElementById(\"name\").innerHTML=
-  eval(document.calc_line.calculator.value)
-}
+define ("JS_CALC_LINE",'
+<div style="border:outset black 3px; position:float; float:right;background-color:white;font-family:sans-serif;font-size:9pt;">
+<script type="text/javascript" language="javascript"  src="js/calc.js">
 </script>
-
-
-
-"
+<h2 class="info"> Calculette</H2>
+<form name="calc_line"  method="GET" onSubmit="cal();return false;" >
+<input style="border:solid 1px;" type="text" size="30" id="inp" name="calculator">
+<input type="button" value="Efface tout" onClick="Clean();return false;" >
+</form>
+<span id="result">  </span><br>
+<span id="sub_total">  Taper un montant puis enter puis le signe et terminer par = </span><br>
+<span id="listing"> </span>
+<br>
+</div>
+'
 );
 
-define ("JS_TVA","<script>
+define ("JS_TVA","<script  language=\"javascript\">
 
 function ChangeTVA(p_ctl,p_value) {
         if (document.getElementById(p_ctl) ) {
-	  document.getElementById(p_ctl).innerHTML=document.forms[0].eval(p_value).value;
+          var f=document.getElementsByName(p_value);
+	  for ( var i=0; i < f.length ; i++) {
+		  document.getElementById(p_ctl).innerHTML=f[i].value;
+	}
 	}
-
 }
 
 </script>");
 // Sql string
 define ("SQL_LIST_ALL_INVOICE","");
+
 define ("SQL_LIST_UNPAID_INVOICE"," where (jr_rapt is null or jr_rapt = '') and jr_valid = true "); 
 define ("SQL_LIST_UNPAID_INVOICE_DATE_LIMIT" ," where (jr_rapt is null or jr_rapt = '') 
                        and to_date(to_char(jr_ech,'DD.MM.YYYY'),'DD.MM.YYYY') < to_date(to_char(now(),'DD.MM.YYYY'),'DD.MM.YYYY') and jr_valid = true" );
